==> google-events-0.3.4.tar.gz: google-events-0.3.4/src/google/events/cloud/iot_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.events.cloud.iot import gapic_version as package_version

__version__ = package_version.__version__



from .types.data import Device
from .types.data import DeviceConfig
from .types.data import DeviceCredential
from .types.data import DeviceEventData
from .types.data import DeviceRegistry
from .types.data import DeviceState
from .types.data import EventNotificationConfig
from .types.data import GatewayConfig
from .types.data import HttpConfig
from .types.data import MqttConfig
from .types.data import PublicKeyCertificate
from .types.data import PublicKeyCredential
from .types.data import RegistryCredential
from .types.data import RegistryEventData
from .types.data import StateNotificationConfig
from .types.data import X509CertificateDetails
from .types.data import GatewayAuthMethod
from .types.data import GatewayType
from .types.data import HttpState
from .types.data import LogLevel
from .types.data import MqttState
from .types.data import PublicKeyCertificateFormat
from .types.data import PublicKeyFormat

__all__ = (
'Device',
'DeviceConfig',
'DeviceCredential',
'DeviceEventData',
'DeviceRegistry',
'DeviceState',
'EventNotificationConfig',
'GatewayAuthMethod',
'GatewayConfig',
'GatewayType',
'HttpConfig',
'HttpState',
'LogLevel',
'MqttConfig',
'MqttState',
'PublicKeyCertificate',
'PublicKeyCertificateFormat',
'PublicKeyCredential',
'PublicKeyFormat',
'RegistryCredential',
'RegistryEventData',
'StateNotificationConfig',
'X509CertificateDetails',
)

==> google-events-0.9.0.tar.gz: google-events-0.9.0/src/google/events/cloud/iot_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.events.cloud.iot_v1 import gapic_version as package_version

__version__ = package_version.__version__



from .types.data import Device
from .types.data import DeviceConfig
from .types.data import DeviceCredential
from .types.data import DeviceEventData
from .types.data import DeviceRegistry
from .types.data import DeviceState
from .types.data import EventNotificationConfig
from .types.data import GatewayConfig
from .types.data import HttpConfig
from .types.data import MqttConfig
from .types.data import PublicKeyCertificate
from .types.data import PublicKeyCredential
from .types.data import RegistryCredential
from .types.data import RegistryEventData
from .types.data import StateNotificationConfig
from .types.data import X509CertificateDetails
from .types.data import GatewayAuthMethod
from .types.data import GatewayType
from .types.data import HttpState
from .types.data import LogLevel
from .types.data import MqttState
from .types.data import PublicKeyCertificateFormat
from .types.data import PublicKeyFormat

__all__ = (
'Device',
'DeviceConfig',
'DeviceCredential',
'DeviceEventData',
'DeviceRegistry',
'DeviceState',
'EventNotificationConfig',
'GatewayAuthMethod',
'GatewayConfig',
'GatewayType',
'HttpConfig',
'HttpState',
'LogLevel',
'MqttConfig',
'MqttState',
'PublicKeyCertificate',
'PublicKeyCertificateFormat',
'PublicKeyCredential',
'PublicKeyFormat',
'RegistryCredential',
'RegistryEventData',
'StateNotificationConfig',
'X509CertificateDetails',
)
